You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airflow.apache.org by po...@apache.org on 2022/01/22 15:49:25 UTC

[airflow] 12/33: Be build -> built, and a stray space (#20703)

This is an automated email from the ASF dual-hosted git repository.

potiuk pushed a commit to branch v2-2-test
in repository https://gitbox.apache.org/repos/asf/airflow.git

commit f86cea1c32ddf6c69446370c7b9eefa13c294304
Author: Tzu-ping Chung <tp...@astronomer.io>
AuthorDate: Thu Jan 6 18:47:57 2022 +0800

    Be build -> built, and a stray space (#20703)
    
    (cherry picked from commit 73472e0b7cab5030c69a43196e3b392722b3da58)
---
 BREEZE.rst                            | 2 +-
 CI.rst                                | 2 +-
 PULL_REQUEST_WORKFLOW.rst             | 2 +-
 airflow/dag_processing/manager.py     | 2 +-
 breeze                                | 8 ++++----
 scripts/ci/libraries/_build_images.sh | 8 ++++----
 6 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/BREEZE.rst b/BREEZE.rst
index 44fa98d..31babf2 100644
--- a/BREEZE.rst
+++ b/BREEZE.rst
@@ -645,7 +645,7 @@ python dependencies, additional Airflow extras. Breeze's ``build-image`` command
 customized variant of the image that contains everything you need.
 
 You can switch to building the production image by adding ``--production-image`` flag to the ``build_image``
-command. Note, that the images can also be build using ``docker build`` command by passing appropriate
+command. Note, that the images can also be built using ``docker build`` command by passing appropriate
 build-args as described in `IMAGES.rst <IMAGES.rst>`_ , but Breeze provides several flags that
 makes it easier to do it. You can see all the flags by running ``./breeze build-image --help``,
 but here typical examples are presented:
diff --git a/CI.rst b/CI.rst
index 6cc97cc..0ea9d6c 100644
--- a/CI.rst
+++ b/CI.rst
@@ -474,7 +474,7 @@ Scheduled runs
 Those runs are results of (nightly) triggered job - only for ``main`` branch. The
 main purpose of the job is to check if there was no impact of external dependency changes on the Apache
 Airflow code (for example transitive dependencies released that fail the build). It also checks if the
-Docker images can be build from the scratch (again - to see if some dependencies have not changed - for
+Docker images can be built from the scratch (again - to see if some dependencies have not changed - for
 example downloaded package releases etc.
 
 All runs consist of the same jobs, but the jobs behave slightly differently or they are skipped in different
diff --git a/PULL_REQUEST_WORKFLOW.rst b/PULL_REQUEST_WORKFLOW.rst
index 379ede8..96c2e00 100644
--- a/PULL_REQUEST_WORKFLOW.rst
+++ b/PULL_REQUEST_WORKFLOW.rst
@@ -171,7 +171,7 @@ The logic implemented for the changes works as follows:
     Quarantined tests are described in `TESTING.rst <TESTING.rst>`_
 
 11) There is a special case of static checks. In case the above logic determines that the CI image
-    needs to be build, we run long and more comprehensive version of static checks - including
+    needs to be built, we run long and more comprehensive version of static checks - including
     Mypy, Flake8. And those tests are run on all files, no matter how many files changed.
     In case the image is not built, we run only simpler set of changes - the longer static checks
     that require CI image are skipped, and we only run the tests on the files that changed in the incoming
diff --git a/airflow/dag_processing/manager.py b/airflow/dag_processing/manager.py
index 00bffc5..6c78aa6 100644
--- a/airflow/dag_processing/manager.py
+++ b/airflow/dag_processing/manager.py
@@ -440,7 +440,7 @@ class DagFileProcessorManager(LoggingMixin):
         if conf.get('core', 'sql_alchemy_conn').startswith('sqlite') and self._parallelism > 1:
             self.log.warning(
                 "Because we cannot use more than 1 thread (parsing_processes = "
-                "%d ) when using sqlite. So we set parallelism to 1.",
+                "%d) when using sqlite. So we set parallelism to 1.",
                 self._parallelism,
             )
             self._parallelism = 1
diff --git a/breeze b/breeze
index c646e08..dccdd6b 100755
--- a/breeze
+++ b/breeze
@@ -973,7 +973,7 @@ function breeze::parse_arguments() {
             echo "Clean build of images without cache"
             echo
             export DOCKER_CACHE="disabled"
-            # if not set here, docker cached is determined later, depending on type of image to be build
+            # if not set here, docker cached is determined later, depending on type of image to be built
             export FORCE_BUILD_IMAGES="true"
             shift
             ;;
@@ -988,21 +988,21 @@ function breeze::parse_arguments() {
             echo "Use local cache to build images"
             echo
             export DOCKER_CACHE="local"
-            # if not set here, docker cached is determined later, depending on type of image to be build
+            # if not set here, docker cached is determined later, depending on type of image to be built
             shift
             ;;
         -U | --build-cache-pulled)
             echo "Use pulled cache to build images"
             echo
             export DOCKER_CACHE="pulled"
-            # if not set here, docker cached is determined later, depending on type of image to be build
+            # if not set here, docker cached is determined later, depending on type of image to be built
             shift
             ;;
         -X | --build-cache-disabled)
             echo "Use disabled cache to build images"
             echo
             export DOCKER_CACHE="disabled"
-            # if not set here, docker cached is determined later, depending on type of image to be build
+            # if not set here, docker cached is determined later, depending on type of image to be built
             shift
             ;;
         -P | --force-pull-images)
diff --git a/scripts/ci/libraries/_build_images.sh b/scripts/ci/libraries/_build_images.sh
index ec3608b..e0a2a8a 100644
--- a/scripts/ci/libraries/_build_images.sh
+++ b/scripts/ci/libraries/_build_images.sh
@@ -111,7 +111,7 @@ function build_images::confirm_via_terminal() {
     echo >"${DETECTED_TERMINAL}"
     set +u
     if [[ ${#MODIFIED_FILES[@]} != "" ]]; then
-        echo "${COLOR_YELLOW}The CI image for Python ${PYTHON_BASE_IMAGE} image likely needs to be rebuild${COLOR_RESET}" >"${DETECTED_TERMINAL}"
+        echo "${COLOR_YELLOW}The CI image for Python ${PYTHON_BASE_IMAGE} image likely needs to be rebuilt${COLOR_RESET}" >"${DETECTED_TERMINAL}"
         echo "${COLOR_YELLOW}The files were modified since last build: ${MODIFIED_FILES[*]}${COLOR_RESET}" >"${DETECTED_TERMINAL}"
     fi
     if [[ ${ACTION} == "pull and rebuild" ]]; then
@@ -129,8 +129,8 @@ function build_images::confirm_via_terminal() {
     RES=$?
 }
 
 # Confirms if the image should be rebuild and interactively checks it with the user.
 # In case iit needs to be rebuild. It only ask the user if it determines that the rebuild
 # is needed and that the rebuild is not already forced. It asks the user using available terminals
 # So that the script works also from within pre-commit run via git hooks - where stdin is not
 # available - it tries to find usable terminal and ask the user via this terminal.
@@ -172,7 +172,7 @@ function build_images::confirm_image_rebuild() {
         echo
         set +u
         if [[ ${#MODIFIED_FILES[@]} != "" ]]; then
-            echo "${COLOR_YELLOW}The CI image for Python ${PYTHON_BASE_IMAGE} image likely needs to be rebuild${COLOR_RESET}"
+            echo "${COLOR_YELLOW}The CI image for Python ${PYTHON_BASE_IMAGE} image likely needs to be rebuilt${COLOR_RESET}"
             echo "${COLOR_YELLOW}The files were modified since last build: ${MODIFIED_FILES[*]}${COLOR_RESET}"
         fi
         echo
@@ -129,8 +129,8 @@ function build_images::confirm_via_terminal() {
 }
 
-# Confirms if the image should be rebuild and interactively checks it with the user.
-# In case iit needs to be rebuild. It only ask the user if it determines that the rebuild
+# Confirms if the image should be rebuilt and interactively checks it with the user.
+# In case iit needs to be rebuilt. It only ask the user if it determines that the rebuild
 # is needed and that the rebuild is not already forced. It asks the user using available terminals
 # So that the script works also from within pre-commit run via git hooks - where stdin is not